Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(405)

Unified Diff: third_party/WebKit/Source/core/svg/graphics/SVGImageChromeClient.cpp

Issue 2005693002: Delay SVGImage animations reset while being updated. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/svg/graphics/SVGImage.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/svg/graphics/SVGImageChromeClient.cpp
diff --git a/third_party/WebKit/Source/core/svg/graphics/SVGImageChromeClient.cpp b/third_party/WebKit/Source/core/svg/graphics/SVGImageChromeClient.cpp
index 808438d18b3f2b60fae56ea0b2412429c4fdf910..699d0891a16f1380983d9b815f7d6969b6f72907 100644
--- a/third_party/WebKit/Source/core/svg/graphics/SVGImageChromeClient.cpp
+++ b/third_party/WebKit/Source/core/svg/graphics/SVGImageChromeClient.cpp
@@ -101,11 +101,17 @@ void SVGImageChromeClient::animationTimerFired(Timer<SVGImageChromeClient>*)
// images can't have any so we assert there's no script.
ScriptForbiddenScope forbidScript;
- // The calls below may trigger GCs, so set up the required persistent
- // reference on the ImageResource which owns this SVGImage. By transitivity,
- // that will keep this SVGImageChromeClient object alive.
- Persistent<ImageObserver> protect(m_image->getImageObserver());
- m_image->frameView()->page()->animator().serviceScriptedAnimations(monotonicallyIncreasingTime());
+ // The call below may trigger GCs, so set up the required reference
+ // to the ImageObserver (an ImageResource) which owns this SVGImage.
+ // By transitivity, that will keep this SVGImageChromeClient object alive.
+ //
+ // The update scope will additionally prevent the GCs from indirectly
+ // triggering animations reset over m_image should the ImageResource become
+ // otherwise unreferenced.
+ {
+ SVGImage::UpdateAnimationScope scope(m_image);
+ m_image->frameView()->page()->animator().serviceScriptedAnimations(monotonicallyIncreasingTime());
+ }
m_image->frameView()->updateAllLifecyclePhases();
}
« no previous file with comments | « third_party/WebKit/Source/core/svg/graphics/SVGImage.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698